@@ -124,7 +124,7 @@ space and potentially provoking overlapping peptide signals, biasing peptide qua
 Thus, low MC counts should be favored. Interestingly, it has been shown recently that 
 incorporation of peptides with missed cleavages does not negatively influence protein quantification (see 
 [Chiva, C., Ortega, M., and Sabido, E. Influence of the Digestion Technique, Protease, and Missed 
-Cleavage Peptides in Protein Quantitation. J. Proteome Res. 2014, 13, 3979-86](https://pubs.acs.org/doi/abs/10.1021/pr500294d) ). 
+Cleavage Peptides in Protein Quantitation. J. Proteome Res. 2014, 13, 3979-86](https://doi.org/10.1021/pr500294d) ). 
 However this is true only if all samples show the same degree of digestion. High missed cleavage values 
 can indicate for example, either a) failed digestion, b) a high (post-digestion) protein contamination, or 
 c) a sample with high amounts of unspecifically degraded peptides which are not digested by trypsin. 
